@@ -155,10 +155,10 @@ class GlueDataBrewClient(BaseClient):
         self,
         *,
         Name: str,
-        Input: "InputTypeDef",
+        Input: InputTypeDef,
         Format: InputFormatType = ...,
-        FormatOptions: "FormatOptionsTypeDef" = ...,
-        PathOptions: "PathOptionsTypeDef" = ...,
+        FormatOptions: FormatOptionsTypeDef = ...,
+        PathOptions: PathOptionsTypeDef = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateDatasetResponseTypeDef:
         """
@@ -173,18 +173,18 @@ class GlueDataBrewClient(BaseClient):
         *,
         DatasetName: str,
         Name: str,
-        OutputLocation: "S3LocationTypeDef",
+        OutputLocation: S3LocationTypeDef,
         RoleArn: str,
         EncryptionKeyArn: str = ...,
         EncryptionMode: EncryptionModeType = ...,
         LogSubscription: LogSubscriptionType = ...,
         MaxCapacity: int = ...,
         MaxRetries: int = ...,
-        Configuration: "ProfileConfigurationTypeDef" = ...,
-        ValidationConfigurations: Sequence["ValidationConfigurationTypeDef"] = ...,
+        Configuration: ProfileConfigurationTypeDef = ...,
+        ValidationConfigurations: Sequence[ValidationConfigurationTypeDef] = ...,
         Tags: Mapping[str, str] = ...,
         Timeout: int = ...,
-        JobSample: "JobSampleTypeDef" = ...
+        JobSample: JobSampleTypeDef = ...
     ) -> CreateProfileJobResponseTypeDef:
         """
         Creates a new job to analyze a dataset and create its data profile.
@@ -200,7 +200,7 @@ class GlueDataBrewClient(BaseClient):
         Name: str,
         RecipeName: str,
         RoleArn: str,
-        Sample: "SampleTypeDef" = ...,
+        Sample: SampleTypeDef = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateProjectResponseTypeDef:
         """
@@ -214,7 +214,7 @@ class GlueDataBrewClient(BaseClient):
         self,
         *,
         Name: str,
-        Steps: Sequence["RecipeStepTypeDef"],
+        Steps: Sequence[RecipeStepTypeDef],
         Description: str = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateRecipeResponseTypeDef:
@@ -236,11 +236,11 @@ class GlueDataBrewClient(BaseClient):
         LogSubscription: LogSubscriptionType = ...,
         MaxCapacity: int = ...,
         MaxRetries: int = ...,
-        Outputs: Sequence["OutputTypeDef"] = ...,
-        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = ...,
-        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = ...,
+        Outputs: Sequence[OutputTypeDef] = ...,
+        DataCatalogOutputs: Sequence[DataCatalogOutputTypeDef] = ...,
+        DatabaseOutputs: Sequence[DatabaseOutputTypeDef] = ...,
         ProjectName: str = ...,
-        RecipeReference: "RecipeReferenceTypeDef" = ...,
+        RecipeReference: RecipeReferenceTypeDef = ...,
         Tags: Mapping[str, str] = ...,
         Timeout: int = ...
     ) -> CreateRecipeJobResponseTypeDef:
@@ -258,7 +258,7 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         TargetArn: str,
-        Rules: Sequence["RuleTypeDef"],
+        Rules: Sequence[RuleTypeDef],
         Description: str = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateRulesetResponseTypeDef:
@@ -516,10 +516,10 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         Preview: bool = ...,
-        RecipeStep: "RecipeStepTypeDef" = ...,
+        RecipeStep: RecipeStepTypeDef = ...,
         StepIndex: int = ...,
         ClientSessionId: str = ...,
-        ViewFrame: "ViewFrameTypeDef" = ...
+        ViewFrame: ViewFrameTypeDef = ...
     ) -> SendProjectSessionActionResponseTypeDef:
         """
         Performs a recipe step within an interactive DataBrew session that's currently
@@ -577,10 +577,10 @@ class GlueDataBrewClient(BaseClient):
         self,
         *,
         Name: str,
-        Input: "InputTypeDef",
+        Input: InputTypeDef,
         Format: InputFormatType = ...,
-        FormatOptions: "FormatOptionsTypeDef" = ...,
-        PathOptions: "PathOptionsTypeDef" = ...
+        FormatOptions: FormatOptionsTypeDef = ...,
+        PathOptions: PathOptionsTypeDef = ...
     ) -> UpdateDatasetResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew dataset.
@@ -593,17 +593,17 @@ class GlueDataBrewClient(BaseClient):
         self,
         *,
         Name: str,
-        OutputLocation: "S3LocationTypeDef",
+        OutputLocation: S3LocationTypeDef,
         RoleArn: str,
-        Configuration: "ProfileConfigurationTypeDef" = ...,
+        Configuration: ProfileConfigurationTypeDef = ...,
         EncryptionKeyArn: str = ...,
         EncryptionMode: EncryptionModeType = ...,
         LogSubscription: LogSubscriptionType = ...,
         MaxCapacity: int = ...,
         MaxRetries: int = ...,
-        ValidationConfigurations: Sequence["ValidationConfigurationTypeDef"] = ...,
+        ValidationConfigurations: Sequence[ValidationConfigurationTypeDef] = ...,
         Timeout: int = ...,
-        JobSample: "JobSampleTypeDef" = ...
+        JobSample: JobSampleTypeDef = ...
     ) -> UpdateProfileJobResponseTypeDef:
         """
         Modifies the definition of an existing profile job.
@@ -613,7 +613,7 @@ class GlueDataBrewClient(BaseClient):
         """
 
     def update_project(
-        self, *, RoleArn: str, Name: str, Sample: "SampleTypeDef" = ...
+        self, *, RoleArn: str, Name: str, Sample: SampleTypeDef = ...
     ) -> UpdateProjectResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew project.
@@ -623,7 +623,7 @@ class GlueDataBrewClient(BaseClient):
         """
 
     def update_recipe(
-        self, *, Name: str, Description: str = ..., Steps: Sequence["RecipeStepTypeDef"] = ...
+        self, *, Name: str, Description: str = ..., Steps: Sequence[RecipeStepTypeDef] = ...
     ) -> UpdateRecipeResponseTypeDef:
         """
         Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
@@ -642,9 +642,9 @@ class GlueDataBrewClient(BaseClient):
         LogSubscription: LogSubscriptionType = ...,
         MaxCapacity: int = ...,
         MaxRetries: int = ...,
-        Outputs: Sequence["OutputTypeDef"] = ...,
-        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = ...,
-        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = ...,
+        Outputs: Sequence[OutputTypeDef] = ...,
+        DataCatalogOutputs: Sequence[DataCatalogOutputTypeDef] = ...,
+        DatabaseOutputs: Sequence[DatabaseOutputTypeDef] = ...,
         Timeout: int = ...
     ) -> UpdateRecipeJobResponseTypeDef:
         """
@@ -655,7 +655,7 @@ class GlueDataBrewClient(BaseClient):
         """
 
     def update_ruleset(
-        self, *, Name: str, Rules: Sequence["RuleTypeDef"], Description: str = ...
+        self, *, Name: str, Rules: Sequence[RuleTypeDef], Description: str = ...
     ) -> UpdateRulesetResponseTypeDef:
         """
         Updates specified ruleset.
